@@ -277,6 +277,12 @@ class JavadocRestCompiler(object):
                 else:
                     package_parts.append(part)
 
+
+            # If the import's final part wasn't capitalized,
+            # append it to the class parts anyway so sphinx doesn't complain.
+            if cls_parts == []:
+                cls_parts.append(package_parts.pop())
+
             package = '.'.join(package_parts)
             cls = '.'.join(cls_parts)
 
